Rucio Clients Examples — Rucio 0.3.8 documentation

# Rucio Clients Examples

Below are some examples of using Rucio’s Client class. We assume that there is a Rucio server running on the localhost on port 80/443.

## Service

### `ping`

Discover server version information.

                remove('/tmp/' + getuser() + '/.rucio_root/auth_token_root')
            except OSError, e:
                if e.args[0] != 2:
                    raise e

## Account

### `create_account`

Add an account.